@@ -4,25 +4,35 @@ __path__ = extend_path(__path__, __name__)
 
 import jijbench.functions as functions
 import jijbench.node as node
-from jijbench.benchmark.benchmark import Benchmark, construct_benchmark_for
+from jijbench.benchmark.benchmark import Benchmark, benchmark_for
+from jijbench.benchmark.decorator import checkpoint
 from jijbench.containers.containers import Artifact, Record, Table
-from jijbench.datasets.instance_data import get_instance_data
-from jijbench.datasets.problem import get_problem
+from jijbench.datasets.model import get_instance_data, get_models, get_problem
 from jijbench.elements.array import Array
 from jijbench.elements.base import Callable, Number, String
 from jijbench.elements.date import Date
 from jijbench.elements.id import ID
 from jijbench.evaluation.evaluation import Evaluation
-from jijbench.experiment.experiment import Experiment
+from jijbench.experiment.experiment import (
+    Experiment,
+    get_benchmark_ids,
+    get_experiment_ids,
+    get_id_table,
+)
 from jijbench.io.io import load, save
 from jijbench.solver.base import Parameter, Response, Solver
-from jijbench.solver.jijzept import InstanceData, SampleSet, UserDefinedModel
+from jijbench.solver.jijzept import InstanceData, Model, SampleSet
 
 __all__ = [
-    "construct_benchmark_for",
+    "checkpoint",
+    "benchmark_for",
     "functions",
     "node",
+    "get_benchmark_ids",
+    "get_experiment_ids",
+    "get_id_table",
     "get_instance_data",
+    "get_models",
     "get_problem",
     "load",
     "save",
@@ -35,7 +45,7 @@ __all__ = [
     "Experiment",
     "ID",
     "InstanceData",
-    "UserDefinedModel",
+    "Model",
     "Number",
     "Parameter",
     "Record",
